==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/APMSCENARIOPMSCHEDULEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour APMSCENARIOPMSCHEDULEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="APMSCENARIOPMSCHEDULEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APMSCENARIOID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PPMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APMSCENARIOPMSCHEDULEID_Type", propOrder = {
    "apmscenarioid",
    "ppmid"
})
public class APMSCENARIOPMSCHEDULEID_Type {

    @XmlElement(name = "APMSCENARIOID", required = true)
    protected STANDARDENTITYID_Type apmscenarioid;
    @XmlElement(name = "PPMID", required = true)
    protected PPM_Type ppmid;

    /**
     * Obtient la valeur de la propriété apmscenarioid.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getAPMSCENARIOID() {
        return apmscenarioid;
    }

    /**
     * Définit la valeur de la propriété apmscenarioid.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setAPMSCENARIOID(STANDARDENTITYID_Type value) {
        this.apmscenarioid = value;
    }

    /**
     * Obtient la valeur de la propriété ppmid.
     * 
     * @return
     *     possible object is
     *     {@link PPM_Type }
     *     
     */
    public PPM_Type getPPMID() {
        return ppmid;
    }

    /**
     * Définit la valeur de la propriété ppmid.
     * 
     * @param value
     *     allowed object is
     *     {@link PPM_Type }
     *     
     */
    public void setPPMID(PPM_Type value) {
        this.ppmid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/APMSCENARIOPMSCHEDULEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for APMSCENARIOPMSCHEDULEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="APMSCENARIOPMSCHEDULEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APMSCENARIOID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PPMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APMSCENARIOPMSCHEDULEID_Type", propOrder = {
    "apmscenarioid",
    "ppmid"
})
public class APMSCENARIOPMSCHEDULEID_Type {

    @XmlElement(name = "APMSCENARIOID", required = true)
    protected STANDARDENTITYID_Type apmscenarioid;
    @XmlElement(name = "PPMID", required = true)
    protected PPM_Type ppmid;

    /**
     * Gets the value of the apmscenarioid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getAPMSCENARIOID() {
        return apmscenarioid;
    }

    /**
     * Sets the value of the apmscenarioid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setAPMSCENARIOID(STANDARDENTITYID_Type value) {
        this.apmscenarioid = value;
    }

    /**
     * Gets the value of the ppmid property.
     * 
     * @return
     *     possible object is
     *     {@link PPM_Type }
     *     
     */
    public PPM_Type getPPMID() {
        return ppmid;
    }

    /**
     * Sets the value of the ppmid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PPM_Type }
     *     
     */
    public void setPPMID(PPM_Type value) {
        this.ppmid = value;
    }

}
